'use strict';
const rp = require('request-promise-native');

const ABBY_EXPERIMENTS_KEY = Symbol('__abbyExperiments');
const ABBY_TIMEOUT_KEY = Symbol('__abbyTimeout');
const UPDATE_INTERVAL = 60000 * 5; // 5 minutes

let load = async (/**Configs*/configs) => {
    try {
        let options = {
            uri: `${configs.apiEndpoint}/experiments`,
            qs: {
                tag: [configs.tags]
            },
            json: true
        };

        let /**Array.<Experiment>*/experiments = await rp(options);
        global[ABBY_EXPERIMENTS_KEY] = experiments;

        return experiments;
    } catch (e) {
        // eslint-disable-next-line no-console
        console.error(`abby-client cannot load experiments: ${configs.apiEndpoint}, tags: ${configs.tags}`);
        return [];
    } finally {
        if (!global[ABBY_TIMEOUT_KEY]) {
            global[ABBY_TIMEOUT_KEY] = setTimeout(() => load(configs), UPDATE_INTERVAL);
        }
    }
};


let sync = {
    load
};

Object.defineProperty(sync, 'data', {
    get: () => {
        return global[ABBY_EXPERIMENTS_KEY];
    }
});

module.exports = sync;
